'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const index = require('./index-a5939648.js');
const MonitoringLabel = require('./MonitoringLabel-1aea858f.js');

const ruxMonitoringIconCss = ":host{display:inline-flex;padding:0}:host([hidden]){display:none}*,*::before,*::after{box-sizing:border-box}.rux-advanced-status{display:flex;flex-direction:column;justify-content:flex-start;position:relative;margin:var(--spacing-0, 0rem);line-height:0;font-family:var(--font-body-1-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-body-1-font-size, 1rem);font-weight:var(--font-body-1-font-weight, 400);letter-spacing:var(--font-body-1-letter-spacing, 0.005em);-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.rux-advanced-status__icon-group{display:flex;position:relative;margin:var(--spacing-0, 0rem) auto;width:calc(var(--spacing-16, 4rem) + var(--spacing-2, 0.5rem))}rux-icon{order:2;margin:0 auto}.rux-advanced-status__status{position:absolute;margin:0}.rux-advanced-status__badge{display:block;z-index:2;order:3;position:absolute;left:calc(var(--spacing-14, 3.5rem) - var(--spacing-050, 0.125rem));top:calc(var(--spacing-025, 0.0625rem) * -5);box-shadow:inset 0 0 0 1px var(--color-text-secondary, #d4d8dd);border-radius:var(--radius-base, 3px);padding:var(--spacing-2, 0.5rem) var(--spacing-1, 0.25rem);color:var(--color-palette-neutral-000, #ffffff);font-family:var(--font-body-3-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-body-3-font-size, 0.75rem);font-weight:var(--font-body-3-font-weight, 400);letter-spacing:var(--font-body-3-letter-spacing, 0.005em);text-align:center;overflow:hidden;text-overflow:ellipsis;white-space:nowrap;background-color:#000}.rux-advanced-status__label{color:var(--color-text-primary, #ffffff);font-family:var(--font-body-2-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-body-2-font-size, 0.875rem);font-weight:var(--font-body-2-font-weight, 400);letter-spacing:var(--font-body-2-letter-spacing, 0.005em);text-align:center;text-overflow:ellipsis;white-space:nowrap;line-height:var(--line-height-sm, 1.25rem);overflow:hidden;width:100%;max-width:calc(var(--spacing-24, 6rem) + var(--spacing-2, 0.5rem))}.rux-advanced-status__sublabel{font-family:var(--font-body-3-font-family, 'Roboto', -apple-system, BlinkMacSystemFont, 'Segoe UI', Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif);font-size:var(--font-body-3-font-size, 0.75rem);font-weight:var(--font-body-3-font-weight, 400);letter-spacing:var(--font-body-3-letter-spacing, 0.005em);color:var(--gsb-color-text, #ffffff);display:block}.rux-advanced-status__status rux-status::part(status){line-height:0}.rux-advanced-status__hidden{display:none}:host([status=off]) rux-icon{color:var(--status-symbol-color-fill-off-on-dark, #a4abb6)}:host([status=standby]) rux-icon{color:var(--status-symbol-color-fill-standby-on-dark, #2dccff)}:host([status=normal]) rux-icon{color:var(--status-symbol-color-fill-normal-on-dark, #56f000)}:host([status=caution]) rux-icon{color:var(--status-symbol-color-fill-caution-on-dark, #fce83a)}:host([status=serious]) rux-icon{color:var(--status-symbol-color-fill-serious-on-dark, #ffb302)}:host([status=critical]) rux-icon{color:var(--status-symbol-color-fill-critical-on-dark, #ff3838)}";

const RuxMonitoringIcon = class {
  constructor(hostRef) {
    index.registerInstance(this, hostRef);
    this.status = 'normal';
    this.label = undefined;
    this.sublabel = undefined;
    this.icon = 'antenna-transmit';
    this.size = '2.5rem';
    this.notifications = 0;
  }
  componentDidRender() {
    this.handleNotificatonWidth();
  }
  validateStatus(newValue) {
    const statusTypes = {
      off: true,
      standby: true,
      normal: true,
      caution: true,
      serious: true,
      critical: true,
    };
    if (!statusTypes[newValue]) {
      throw new Error('valid status required');
    }
  }
  handleNotificatonWidth() {
    const badge = this.el.shadowRoot.querySelector('.rux-advanced-status__badge');
    if (badge) {
      /** Size and position of the icon. */
      const iconRect = this.el.getBoundingClientRect();
      /** Size and position of the badge. */
      const badgeRect = badge.getBoundingClientRect();
      /** Offset between the right-edge of the badge and the right-edge of the icon. */
      const offset = badgeRect.right - iconRect.right;
      // if the offset is greater than zero, increase the minimum width of the badge
      if (offset > 0) {
        this.el.style.minWidth = iconRect.width + offset + 'px';
      }
    }
  }
  render() {
    return (index.h("div", { id: "rux-advanced-status__icon", class: "rux-advanced-status", part: "container" }, index.h("div", { class: "rux-advanced-status__icon-group" }, index.h("div", { class: "rux-advanced-status__status" }, index.h("rux-status", { status: this.status, part: "status-icon" })), index.h("rux-icon", { icon: this.icon, class: `rux-status--${this.status}`, size: this.size, exportparts: "icon" }), index.h(MonitoringLabel.MonitoringBadge, { notifications: this.notifications })), index.h(MonitoringLabel.MonitoringLabel, { label: this.label, sublabel: this.sublabel })));
  }
  get el() { return index.getElement(this); }
  static get watchers() { return {
    "status": ["validateStatus"]
  }; }
};
RuxMonitoringIcon.style = ruxMonitoringIconCss;

exports.rux_monitoring_icon = RuxMonitoringIcon;
